==> blink-components-0.5.3.tgz: package/components/TextInput/index.js <==
// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import { FormField } from 'react-form'
import Icon from 'components/Icon'

class TextInput extends React.PureComponent {
  props: {
    field: string,
    type: string,
    multiline: boolean,
    icon: string,
    label?: string,
    className?: string,
    theme: { [key: string]: string},
  };

  ref: any;

  static defaultProps = {
    className: undefined,
    label: undefined,
  }

  render() {
    const {
      field,
      type = 'text',
      multiline = false,
      icon,
      label,
      className,
      theme,
      ...rest
    } = this.props
    const Input = multiline ? 'textarea' : 'input'
    return (
      <FormField
        className={cn(theme.root, className)}
        field={field}
        showErrors={false}
      >
        {({ setValue, getValue, setTouched }) => (
          <div onClick={() => this.ref.focus()}>
            {!!label && (
              <label className={theme.label} htmlFor={field}>{label}</label>
            )}
            <div className="flex items-center">
              {!!icon && (
                <Icon key="icon" className={theme.icon} name={icon} />
              )}
              <Input
                key="input"
                ref={(ref) => { this.ref = ref }}
                name={field}
                className={cn('flex-auto input-reset outline-0 bn', theme.input)}
                type={type}
                {...rest} // Send the rest of your props to React-Select
                value={getValue()} // Set the value to the forms value
                onChange={(e) => {
                  setValue(e.target.value)
                }} // On Change, update the form value
                onBlur={() => setTouched()}
              />
            </div>
          </div>
        )}
      </FormField>
    )
  }
}

export default themr('TextInput', {}, { composeTheme: 'softly' })(TextInput)

==> blink-components-0.10.4.tgz: package/components/TextInput/index.js <==
// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import { FormField } from 'react-form'
import Icon from 'components/Icon'

class TextInput extends React.PureComponent {
  props: {
    field: string,
    type: string,
    multiline: boolean,
    icon: string,
    label?: string,
    className?: string,
    theme: { [key: string]: string},
  };

  ref: any;

  static defaultProps = {
    className: undefined,
    label: undefined,
  }

  render() {
    const {
      field,
      type = 'text',
      multiline = false,
      icon,
      label,
      className,
      theme,
      ...rest
    } = this.props
    const Input = multiline ? 'textarea' : 'input'
    return (
      <FormField
        field={field}
        showErrors={false}
      >
        {({ setValue, getValue, setTouched }) => (
          <div className={cn(theme.root, className)} onClick={() => this.ref.focus()}>
            {!!label && (
              <label className={theme.label} htmlFor={field}>{label}</label>
            )}
            <div className="flex items-center">
              {!!icon && (
                <Icon key="icon" className={theme.icon} name={icon} />
              )}
              <Input
                key="input"
                ref={(ref) => { this.ref = ref }}
                name={field}
                className={cn('flex-auto input-reset outline-0 bn', theme.input)}
                type={type}
                {...rest} // Send the rest of your props to React-Select
                value={getValue()} // Set the value to the forms value
                onChange={(e) => {
                  setValue(e.target.value)
                }} // On Change, update the form value
                onBlur={() => setTouched()}
              />
            </div>
          </div>
        )}
      </FormField>
    )
  }
}

export default themr('TextInput', {}, { composeTheme: 'softly' })(TextInput)
